lxm3.xm\_cluster.SingularityContainer
=====================================

.. currentmodule:: lxm3.xm_cluster

.. autoclass:: SingularityContainer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SingularityContainer.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SingularityContainer.name
      ~SingularityContainer.entrypoint
      ~SingularityContainer.image_path
   
   